@@ -1,18 +1,21 @@
 from __future__ import absolute_import, unicode_literals
 
 import uuid
-from copy import copy
 from collections import defaultdict
+from copy import copy
 
-from django.conf.urls import patterns, url
+from django.conf.urls import url
 from django.db import connections
 from django.utils.translation import ugettext_lazy as _, ungettext_lazy as __
 
 from debug_toolbar.panels import Panel
+from debug_toolbar.panels.sql import views
 from debug_toolbar.panels.sql.forms import SQLSelectForm
+from debug_toolbar.panels.sql.tracking import unwrap_cursor, wrap_cursor
+from debug_toolbar.panels.sql.utils import (
+    contrasting_color_generator, reformat_sql,
+)
 from debug_toolbar.utils import render_stacktrace
-from debug_toolbar.panels.sql.utils import reformat_sql, contrasting_color_generator
-from debug_toolbar.panels.sql.tracking import wrap_cursor, unwrap_cursor
 
 
 def get_isolation_level_display(vendor, level):
@@ -120,11 +123,11 @@ class SQLPanel(Panel):
 
     @classmethod
     def get_urls(cls):
-        return patterns('debug_toolbar.panels.sql.views',               # noqa
-            url(r'^sql_select/$', 'sql_select', name='sql_select'),
-            url(r'^sql_explain/$', 'sql_explain', name='sql_explain'),
-            url(r'^sql_profile/$', 'sql_profile', name='sql_profile'),
-        )
+        return [
+            url(r'^sql_select/$', views.sql_select, name='sql_select'),
+            url(r'^sql_explain/$', views.sql_explain, name='sql_explain'),
+            url(r'^sql_profile/$', views.sql_profile, name='sql_profile'),
+        ]
 
     def enable_instrumentation(self):
         # This is thread-safe because database connections are thread-local.
@@ -135,9 +138,10 @@ class SQLPanel(Panel):
         for connection in connections.all():
             unwrap_cursor(connection)
 
-    def process_response(self, request, response):
+    def generate_stats(self, request, response):
         colors = contrasting_color_generator()
         trace_colors = defaultdict(lambda: next(colors))
+        query_duplicates = defaultdict(lambda: defaultdict(int))
         if self._queries:
             width_ratio_tally = 0
             factor = int(256.0 / (len(self._databases) * 2.5))
@@ -160,6 +164,8 @@ class SQLPanel(Panel):
             trans_id = None
             i = 0
             for alias, query in self._queries:
+                query_duplicates[alias][query["raw_sql"]] += 1
+
                 trans_id = query.get('trans_id')
                 last_trans_id = trans_ids.get(alias)
 
@@ -203,6 +209,30 @@ class SQLPanel(Panel):
             if trans_id:
                 self._queries[(i - 1)][1]['ends_trans'] = True
 
+        # Queries are duplicates only if there's as least 2 of them.
+        # Also, to hide queries, we need to give all the duplicate groups an id
+        query_duplicates = dict(
+            (alias, dict(
+                (query, duplicate_count)
+                for query, duplicate_count in queries.items()
+                if duplicate_count >= 2
+            ))
+            for alias, queries in query_duplicates.items()
+        )
+
+        for alias, query in self._queries:
+            try:
+                duplicates_count = query_duplicates[alias][query["raw_sql"]]
+                query["duplicate_count"] = duplicates_count
+            except KeyError:
+                pass
+
+        for alias, alias_info in self._databases.items():
+            try:
+                alias_info["duplicate_count"] = sum(e for e in query_duplicates[alias].values())
+            except KeyError:
+                pass
+
         self.record_stats({
             'databases': sorted(self._databases.items(), key=lambda x: -x[1]['time_spent']),
             'queries': [q for a, q in self._queries],
