@@ -1,11 +1,11 @@
 from __future__ import absolute_import, unicode_literals
 
 import warnings
+from importlib import import_module
 
 from django.conf import settings
-from django.utils.importlib import import_module
 from django.utils import six
-
+from django.utils.module_loading import import_string
 
 # Always import this module as follows:
 # from debug_toolbar import settings [as dt_settings]
@@ -18,9 +18,9 @@ CONFIG_DEFAULTS = {
     # Toolbar options
     'DISABLE_PANELS': set(['debug_toolbar.panels.redirects.RedirectsPanel']),
     'INSERT_BEFORE': '</body>',
-    'JQUERY_URL': '//ajax.googleapis.com/ajax/libs/jquery/2.1.0/jquery.min.js',
+    'JQUERY_URL': '//ajax.googleapis.com/ajax/libs/jquery/2.1.4/jquery.min.js',
     'RENDER_PANELS': None,
-    'RESULTS_STORE_SIZE': 10,
+    'RESULTS_CACHE_SIZE': 10,
     'ROOT_TAG_EXTRA_ATTRS': '',
     'SHOW_COLLAPSED': False,
     'SHOW_TOOLBAR_CALLBACK': 'debug_toolbar.middleware.show_toolbar',
@@ -65,10 +65,6 @@ if 'TAG' in USER_CONFIG:
 
 CONFIG = CONFIG_DEFAULTS.copy()
 CONFIG.update(USER_CONFIG)
-if not isinstance(CONFIG['SHOW_TOOLBAR_CALLBACK'], six.string_types):
-    warnings.warn(
-        "SHOW_TOOLBAR_CALLBACK is now a dotted path. Update your "
-        "DEBUG_TOOLBAR_CONFIG setting.", DeprecationWarning)
 
 
 PANELS_DEFAULTS = [
@@ -150,7 +146,6 @@ if 'INTERCEPT_REDIRECTS' in USER_CONFIG:
             'debug_toolbar.panels.redirects.RedirectsPanel'
         )
 
-
 PATCH_SETTINGS = getattr(settings, 'DEBUG_TOOLBAR_PATCH_SETTINGS', settings.DEBUG)
 
 
@@ -158,20 +153,38 @@ PATCH_SETTINGS = getattr(settings, 'DEBUG_TOOLBAR_PATCH_SETTINGS', settings.DEBU
 # imports are placed inside functions to make it safe to import this module.
 
 
-def is_toolbar_middleware(middleware_path):
+def check_middleware():
+    from django.middleware.gzip import GZipMiddleware
     from debug_toolbar.middleware import DebugToolbarMiddleware
-    # This could be replaced by import_by_path in Django >= 1.6.
+    gzip_index = None
+    debug_toolbar_index = None
+
+    # Determine the indexes which gzip and/or the toolbar are installed at
+    for i, middleware in enumerate(settings.MIDDLEWARE_CLASSES):
+        if is_middleware_class(GZipMiddleware, middleware):
+            gzip_index = i
+        elif is_middleware_class(DebugToolbarMiddleware, middleware):
+            debug_toolbar_index = i
+    # If the toolbar appears before the gzip index, raise a warning
+    if gzip_index is not None and debug_toolbar_index < gzip_index:
+        warnings.warn(
+            "Please use an explicit setup with the "
+            "debug_toolbar.middleware.DebugToolbarMiddleware "
+            "after django.middleware.gzip.GZipMiddlware "
+            "in MIDDLEWARE_CLASSES.", Warning)
+
+
+def is_middleware_class(middleware_class, middleware_path):
     try:
-        mod_path, cls_name = middleware_path.rsplit('.', 1)
-        mod = import_module(mod_path)
-        middleware_cls = getattr(mod, cls_name)
-    except (AttributeError, ImportError, ValueError):
+        middleware_cls = import_string(middleware_path)
+    except ImportError:
         return
-    return issubclass(middleware_cls, DebugToolbarMiddleware)
+    return issubclass(middleware_cls, middleware_class)
 
 
 def is_toolbar_middleware_installed():
-    return any(is_toolbar_middleware(middleware)
+    from debug_toolbar.middleware import DebugToolbarMiddleware
+    return any(is_middleware_class(DebugToolbarMiddleware, middleware)
                for middleware in settings.MIDDLEWARE_CLASSES)
 
 
@@ -196,16 +209,16 @@ def patch_middleware_classes():
 
 
 def patch_root_urlconf():
-    from django.conf.urls import include, patterns, url
+    from django.conf.urls import include, url
     from django.core.urlresolvers import clear_url_caches, reverse, NoReverseMatch
     import debug_toolbar
     try:
         reverse('djdt:render_panel')
     except NoReverseMatch:
         urlconf_module = import_module(settings.ROOT_URLCONF)
-        urlconf_module.urlpatterns = patterns('',                      # noqa
+        urlconf_module.urlpatterns = [
             url(r'^__debug__/', include(debug_toolbar.urls)),
-        ) + urlconf_module.urlpatterns
+        ] + urlconf_module.urlpatterns
         clear_url_caches()
 
 
