@@ -4,21 +4,25 @@ import inspect
 import os.path
 import re
 import sys
+from importlib import import_module
+
+import django
+from django.core.exceptions import ImproperlyConfigured
+from django.template import Node
+from django.utils import six
+from django.utils.encoding import force_text
+from django.utils.html import escape
+from django.utils.safestring import mark_safe
+
+from debug_toolbar.compat import linebreak_iter
+
+from .settings import CONFIG
+
 try:
     import threading
 except ImportError:
     threading = None
 
-import django
-from django.core.exceptions import ImproperlyConfigured
-from django.utils.encoding import force_text
-from django.utils.html import escape
-from django.utils.importlib import import_module
-from django.utils.safestring import mark_safe
-from django.utils import six
-from django.views.debug import linebreak_iter
-
-from .settings import CONFIG
 
 # Figure out some paths
 django_path = os.path.realpath(os.path.dirname(django.__file__))
@@ -71,11 +75,11 @@ def render_stacktrace(trace):
         params = map(escape, frame[0].rsplit(os.path.sep, 1) + list(frame[1:]))
         params_dict = dict((six.text_type(idx), v) for idx, v in enumerate(params))
         try:
-            stacktrace.append('<span class="path">%(0)s/</span>'
-                              '<span class="file">%(1)s</span>'
-                              ' in <span class="func">%(3)s</span>'
-                              '(<span class="lineno">%(2)s</span>)\n'
-                              '  <span class="code">%(4)s</span>'
+            stacktrace.append('<span class="djdt-path">%(0)s/</span>'
+                              '<span class="djdt-file">%(1)s</span>'
+                              ' in <span class="djdt-func">%(3)s</span>'
+                              '(<span class="djdt-lineno">%(2)s</span>)\n'
+                              '  <span class="djdt-code">%(4)s</span>'
                               % params_dict)
         except KeyError:
             # This frame doesn't have the expected format, so skip it and move on to the next one
@@ -83,7 +87,34 @@ def render_stacktrace(trace):
     return mark_safe('\n'.join(stacktrace))
 
 
-def get_template_info(source, context_lines=3):
+def get_template_info():
+    template_info = None
+    cur_frame = sys._getframe().f_back
+    try:
+        while cur_frame is not None:
+            in_utils_module = cur_frame.f_code.co_filename.endswith(
+                "/debug_toolbar/utils.py"
+            )
+            is_get_template_context = (
+                cur_frame.f_code.co_name == get_template_context.__name__
+            )
+            if in_utils_module and is_get_template_context:
+                # If the method in the stack trace is this one
+                # then break from the loop as it's being check recursively.
+                break
+            elif cur_frame.f_code.co_name == 'render':
+                node = cur_frame.f_locals['self']
+                if isinstance(node, Node):
+                    template_info = get_template_context(node.source)
+                    break
+            cur_frame = cur_frame.f_back
+    except Exception:
+        pass
+    del cur_frame
+    return template_info
+
+
+def get_template_context(source, context_lines=3):
     line = 0
     upto = 0
     source_lines = []
