@@ -1,6 +1,7 @@
 """Django settings for example project."""
 
 import os
+
 BASE_DIR = os.path.dirname(os.path.dirname(__file__))
 
 
@@ -25,6 +26,14 @@ INSTALLED_APPS = (
     'debug_toolbar',
 )
 
+MIDDLEWARE_CLASSES = (
+    'django.middleware.common.CommonMiddleware',
+    'django.contrib.sessions.middleware.SessionMiddleware',
+    'django.contrib.auth.middleware.AuthenticationMiddleware',
+    'django.contrib.messages.middleware.MessageMiddleware',
+    'django.middleware.csrf.CsrfViewMiddleware',
+)
+
 ROOT_URLCONF = 'example.urls'
 
 STATIC_URL = '/static/'
