@@ -1,10 +1,8 @@
 from __future__ import absolute_import, unicode_literals
 
-import django
 from django.conf import settings
 from django.http import HttpResponse
 from django.test.utils import override_settings
-from django.utils import unittest
 
 from ..base import BaseTestCase
 
@@ -30,31 +28,50 @@ class RedirectsPanelTestCase(BaseTestCase):
         redirect['Location'] = 'http://somewhere/else/'
         response = self.panel.process_response(self.request, redirect)
         self.assertFalse(response is redirect)
-        self.assertContains(response, '302 FOUND')
+        try:
+            self.assertContains(response, '302 Found')
+        except AssertionError:  # Django < 1.9
+            self.assertContains(response, '302 FOUND')
         self.assertContains(response, 'http://somewhere/else/')
 
     def test_redirect_with_broken_context_processor(self):
-        context_processors = settings.TEMPLATE_CONTEXT_PROCESSORS + (
+        context_processors = list(settings.TEMPLATE_CONTEXT_PROCESSORS) + [
             'tests.context_processors.broken',
-        )
+        ]
 
         with self.settings(TEMPLATE_CONTEXT_PROCESSORS=context_processors):
             redirect = HttpResponse(status=302)
             redirect['Location'] = 'http://somewhere/else/'
             response = self.panel.process_response(self.request, redirect)
             self.assertFalse(response is redirect)
-            self.assertContains(response, '302 FOUND')
+            try:
+                self.assertContains(response, '302 Found')
+            except AssertionError:  # Django < 1.9
+                self.assertContains(response, '302 FOUND')
             self.assertContains(response, 'http://somewhere/else/')
 
     def test_unknown_status_code(self):
         redirect = HttpResponse(status=369)
         redirect['Location'] = 'http://somewhere/else/'
         response = self.panel.process_response(self.request, redirect)
-        self.assertContains(response, '369 UNKNOWN STATUS CODE')
+        try:
+            self.assertContains(response, '369 Unknown Status Code')
+        except AssertionError:  # Django < 1.9
+            self.assertContains(response, '369 UNKNOWN STATUS CODE')
 
-    @unittest.skipIf(django.VERSION[:2] < (1, 6), "reason isn't supported")
     def test_unknown_status_code_with_reason(self):
         redirect = HttpResponse(status=369, reason='Look Ma!')
         redirect['Location'] = 'http://somewhere/else/'
         response = self.panel.process_response(self.request, redirect)
         self.assertContains(response, '369 Look Ma!')
+
+    def test_insert_content(self):
+        """
+        Test that the panel only inserts content after generate_stats and
+        not the process_response.
+        """
+        redirect = HttpResponse(status=304)
+        response = self.panel.process_response(self.request, redirect)
+        self.assertIsNotNone(response)
+        response = self.panel.generate_stats(self.request, redirect)
+        self.assertIsNone(response)
